==> EnbanFukusyaYa-1.12-20040727-src.tar.gz: EnbanFukusyaYa-1.12/Win32/SettingDlg.h <==
/* ~Օʉ
 * Copyright (C) 2004 Kagetani Hideto
 */
#if !defined(AFX_SETTINGDLG_H__CEB3E180_E11F_411B_A0D1_38248C97C821__INCLUDED_)
#define AFX_SETTINGDLG_H__CEB3E180_E11F_411B_A0D1_38248C97C821__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// SettingDlg.h : wb_[ t@C
//

#include <ThemeButton.h>
#include <ThemeLabel.h>
#include <ThemeComboBox.h>
#include <ThemeCheckBox.h>
#include <ThemeDialog.h>
#include <option.h>

/////////////////////////////////////////////////////////////////////////////
// CSettingDlg _CAO

class CSettingDlg : public CThemeDialog
{
// RXgNV
public:
	CSettingDlg(CWnd* pParent = NULL);   // W̃RXgN^

// _CAO f[^
	//{{AFX_DATA(CSettingDlg)
	enum { IDD = IDD_SETTING };
	CThemeLabel	m_StcTempPath;
	CEdit	m_EdtTempPath;
	CThemeButton	m_BtnOK;
	CThemeButton	m_BtnCancel;
	CThemeLabel	m_StcWriteSpeed;
	CThemeLabel	m_StcReadSpeed;
	CThemeComboBox	m_CmbWriteSpeed;
	CThemeComboBox	m_CmbReadSpeed;
	CThemeCheckBox	m_ChkTestWrite;
	CThemeCheckBox	m_ChkOnthefly;
	CThemeCheckBox	m_ChkDAO;
	CThemeCheckBox	m_ChkBUFE;
	//}}AFX_DATA


// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
	//{{AFX_VIRTUAL(CSettingDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV T|[g
	//}}AFX_VIRTUAL

// Cve[V
protected:

	// ꂽbZ[W }bv֐
	//{{AFX_MSG(CSettingDlg)
	virtual BOOL OnInitDialog();
	virtual void OnOK();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()

private:
	void SetSpeedItems(CComboBox *pCB, int nDefaultSpeed, BOOL bDVD);
	OPTIONS *m_pOption;

public:
	void SetData(OPTIONS *pOption){  m_pOption = pOption; };
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_SETTINGDLG_H__CEB3E180_E11F_411B_A0D1_38248C97C821__INCLUDED_)

==> EnbanFukusyaYa-1.18-20060703-src.tar.gz: EnbanFukusyaYa-1.18/Win32/SettingDlg.h <==
/* ~Օʉ
 * Copyright (C) 2004 Kagetani Hideto
 */
#if !defined(AFX_SETTINGDLG_H__CEB3E180_E11F_411B_A0D1_38248C97C821__INCLUDED_)
#define AFX_SETTINGDLG_H__CEB3E180_E11F_411B_A0D1_38248C97C821__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// SettingDlg.h : wb_[ t@C
//

#include <ThemeButton.h>
#include <ThemeLabel.h>
#include <ThemeComboBox.h>
#include <ThemeCheckBox.h>
#include <ThemeDialog.h>
#include <option.h>

/////////////////////////////////////////////////////////////////////////////
// CSettingDlg _CAO

class CSettingDlg : public CThemeDialog
{
// RXgNV
public:
	CSettingDlg(CWnd* pParent = NULL);   // W̃RXgN^

// _CAO f[^
	//{{AFX_DATA(CSettingDlg)
	enum { IDD = IDD_SETTING };
	CThemeLabel	m_StcTempPath;
	CEdit	m_EdtTempPath;
	CThemeButton	m_BtnOK;
	CThemeButton	m_BtnCancel;
	CThemeLabel	m_StcWriteSpeed;
	CThemeLabel	m_StcReadSpeed;
	CThemeComboBox	m_CmbWriteSpeed;
	CThemeComboBox	m_CmbReadSpeed;
	CThemeCheckBox	m_ChkTestWrite;
	CThemeCheckBox	m_ChkOnthefly;
	CThemeCheckBox	m_ChkDAO;
	CThemeCheckBox	m_ChkBUFE;
	//}}AFX_DATA


// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
	//{{AFX_VIRTUAL(CSettingDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV T|[g
	//}}AFX_VIRTUAL

// Cve[V
protected:

	// ꂽbZ[W }bv֐
	//{{AFX_MSG(CSettingDlg)
	virtual BOOL OnInitDialog();
	virtual void OnOK();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()

private:
	void SetSpeedItems(CComboBox *pCB, int nDefaultSpeed, BOOL bDVD,
						BYTE *speeds, int num_speeds);
	OPTIONS *m_pOption;

public:
	void SetData(OPTIONS *pOption){  m_pOption = pOption; };
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_SETTINGDLG_H__CEB3E180_E11F_411B_A0D1_38248C97C821__INCLUDED_)
